svn commit: r206027 - head/sys/kern

Lawrence Stewart lstewart at FreeBSD.org
Thu Apr 1 01:23:36 UTC 2010


Author: lstewart
Date: Thu Apr  1 01:23:36 2010
New Revision: 206027
URL: http://svn.freebsd.org/changeset/base/206027

Log:
  According to SLEEP(9), msleep() is deprecated in favour of mtx_sleep().
  
  Sponsored by:	FreeBSD Foundation
  Reviewed by:	dwmalone, jeff, rpaulo, rwatson (as part of a larger patch)
  Approved by:	kmacy (mentor)
  MFC after:	1 month

Modified:
  head/sys/kern/kern_alq.c

Modified: head/sys/kern/kern_alq.c
==============================================================================
--- head/sys/kern/kern_alq.c	Thu Apr  1 01:16:00 2010	(r206026)
+++ head/sys/kern/kern_alq.c	Thu Apr  1 01:23:36 2010	(r206027)
@@ -191,7 +191,7 @@ ald_daemon(void)
 	for (;;) {
 		while ((alq = LIST_FIRST(&ald_active)) == NULL &&
 		    !ald_shutingdown)
-			msleep(&ald_active, &ald_mtx, PWAIT, "aldslp", 0);
+			mtx_sleep(&ald_active, &ald_mtx, PWAIT, "aldslp", 0);
 
 		/* Don't shutdown until all active ALQs are flushed. */
 		if (ald_shutingdown && alq == NULL) {
@@ -234,12 +234,12 @@ ald_shutdown(void *arg, int howto)
 
 	/*
 	 * Wake ald_daemon so that it exits. It won't be able to do
 	 * anything until we msleep because we hold the ald_mtx.
 	 */
 	wakeup(&ald_active);
 
 	/* Wait for ald_daemon to exit. */
-	msleep(ald_proc, &ald_mtx, PWAIT, "aldslp", 0);
+	mtx_sleep(ald_proc, &ald_mtx, PWAIT, "aldslp", 0);
 
 	ALD_UNLOCK();
 }
@@ -234,12 +234,12 @@ ald_shutdown(void *arg, int howto)
 	/*
 	 * Wake ald_daemon so that it exits. It won't be able to do
-	 * anything until we msleep because we hold the ald_mtx.
+	 * anything until we mtx_sleep because we hold the ald_mtx.
 	 */
 	wakeup(&ald_active);


More information about the svn-src-head mailing list